@@ -307,7 +307,7 @@ void KameraConfigDialog::updateWidgetValue(CameraWidget *widget)
 	}
 }
 
-void KameraConfigDialog::slotOK()
+void KameraConfigDialog::slotOk()
 {
 	// Copy Qt widget values into CameraWidget hierarchy
 	updateWidgetValue(m_widgetRoot);
