@@ -1,3 +1,4 @@
+// -*- C++ -*-
 // fontEncoding.h
 //
 // Part of KDVI - A DVI previewer for the KDE desktop environemt 
@@ -5,16 +6,10 @@
 // (C) 2003 Stefan Kebekus
 // Distributed under the GPL
 
-#include <../config.h>
-#ifdef HAVE_FREETYPE
-
-
 #ifndef _FONTENCODING_H
 #define _FONTENCODING_H
 
-class QString;
-
-#include <qglobal.h>
+#include <qstring.h>
 
 
 /**
@@ -89,4 +84,3 @@ class fontEncoding {
 };
 
 #endif
-#endif // HAVE_FREETYPE
