@@ -5,7 +5,7 @@
 // (C) 2003 Stefan Kebekus
 // Distributed under the GPL
 
-#include <../config.h>
+#include <config.h>
 #ifdef HAVE_FREETYPE
 
 #include <kdebug.h>
@@ -72,7 +72,11 @@ fontMap::fontMap()
       QString FullName = line.section(' ', 1, 1);
       QString fontFileName = line.section('<', -1).stripWhiteSpace().section(' ', 0, 0);
       QString encodingName = line.section('<', -2, -2).stripWhiteSpace().section(' ', 0, 0);
-      
+      // It seems that sometimes the encoding is prepended by the
+      // letter '[', which we ignore
+      if ((!encodingName.isEmpty()) && (encodingName[0] == '['))
+        encodingName = encodingName.mid(1);
+
       double slant = 0.0;
       int i = line.find("SlantFont");
       if (i >= 0) {
