@@ -111,6 +111,9 @@ fontPool::~fontPool()
   kdDebug(4300) << "fontPool::~fontPool() called" << endl;
 #endif
 
+  // need to manually clear the fonts _before_ freetype gets unloaded
+  fontList.clear();
+
 #ifdef HAVE_FREETYPE
   if (FreeType_could_be_loaded == true)
     FT_Done_FreeType( FreeType_library );
