@@ -1,12 +1,17 @@
+// -*- C++ -*-
 // kdvi.h 
 //
 // global variables and definitions for kdvi.
 //
 // (C) 2000, Stefan Kebekus. Distributed under the GPL.
 
+#ifndef KDVI_H
+#define KDVI_H
 
 // Define the following flags to generate debugging output
-  
+
 // #define DEBUG_FONT 1
 // #define DEBUG_FONTPOOL 1
 // #define DEBUG_PK 1
+
+#endif
