@@ -12,34 +12,27 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
- *  $Id: kfile_pdf.h,v 1.5 2002/03/22 20:15:30 aseigo Exp $
+ *  $Id: kfile_pdf.h 652398 2007-04-10 21:55:31Z aacid $
  */
 
 #ifndef __KFILE_PDF_H__
 #define __KFILE_PDF_H__
 
 #include <kfilemetainfo.h>
+#include <poppler-qt.h>
 
 class QStringList;
-class KProcess;
 
 class KPdfPlugin: public KFilePlugin
 {
-    Q_OBJECT
+Q_OBJECT
 public:
     KPdfPlugin( QObject *parent, const char *name, const QStringList& preferredItems );
 
     virtual bool readInfo(KFileMetaInfo& info, uint what);
-
-private slots:
-    void slotReceivedStdout(KProcess* p, char* buffer, int buflen);
-
-private:
-    QDateTime pdfDate(const QString& s) const;
-    KFileMetaInfo mInfo;
 };
 
 #endif
