@@ -12,10 +12,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
- *  $Id: kfile_ps.cpp 323729 2004-06-26 10:13:01Z binner $
+ *  $Id: kfile_ps.cpp 465369 2005-09-29 14:33:08Z mueller $
  */
 
 #include "kfile_ps.h"
@@ -36,8 +36,14 @@ KPSPlugin::KPSPlugin(QObject *parent, const char *name,
 {
     kdDebug(7034) << "ps plugin\n";
     
-    // set up our mimetype
-    KFileMimeTypeInfo* info = addMimeTypeInfo( "application/postscript" );
+    // set up our mimetypes
+    makeMimeTypeInfo( "application/postscript" );
+    makeMimeTypeInfo( "image/x-eps" );
+}
+
+void KPSPlugin::makeMimeTypeInfo( const char* mimeType )
+{
+    KFileMimeTypeInfo* info = addMimeTypeInfo( mimeType );
 
     // general group
     KFileMimeTypeInfo::GroupInfo* group = addGroupInfo(info, "General", i18n("General"));
