@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -142,7 +142,7 @@ void  ConfigDialog::showSettings( KGVPart* main ) {
     dialog->addPage( new GeneralSettingsWidget( 0, "general-settings" ),
 	    i18n( "General" ), QString::fromLatin1( "kghostview" ) );
     GSSettingsWidget *gssw = new GSSettingsWidget( 0, "gs-settings" );
-    dialog->addPage( gssw, i18n( "Ghostscript Configuration" ), QString::fromLatin1( "pdf" ) );
+    dialog->addPage( gssw, i18n( "Ghostscript\nConfiguration" ), QString::fromLatin1( "pdf" ) );
 
     gssw->setDetectedVersion(Configuration::version());
 
