@@ -1250,11 +1250,11 @@ void KIconEditGrid::editPaste(bool paste)
             //kdDebug(4640) << "KIconEditGrid: Pasting at: " << insrect.x() << " x " << insrect.y() << endl;
             QApplication::setOverrideCursor(waitCursor);
 
-            for(int y = insrect.y(), ny = 0; y < numRows(), ny < insrect.height(); y++, ny++)
+            for(int y = insrect.y(), ny = 0; y < numRows() && ny < insrect.height(); y++, ny++)
             {
                 uint *l = ((uint*)img->scanLine(y)+insrect.x());
                 uint *cl = (uint*)tmp.scanLine(ny);
-                for(int x = insrect.x(), nx = 0; x < numCols(), nx < insrect.width(); x++, nx++, l++, cl++)
+                for(int x = insrect.x(), nx = 0; x < numCols() && nx < insrect.width(); x++, nx++, l++, cl++)
                 {
                     if(props->pasteTransparent())
                     {
