@@ -69,17 +69,16 @@ void Indexer::startIndexing( const QStringList& dirs )
 
 void Indexer::processFinished( KProcess *proc )
 {
-    // error handling
-    if ( !proc->normalExit() || proc != m_process )
-    {
-        // ### KMessageBox::error();
-    }
-
     // still more directories to index?
     if ( !m_dirs.isEmpty() )
         processNext();
     else
-        emit finished( proc->normalExit() );
+    {
+        if ( proc->normalExit() )
+            emit finished( proc->exitStatus() );
+	else
+	    emit finished( -1000 );
+    }
 }
 
 
