@@ -152,8 +152,7 @@ bool kpGrip::isDrawing () const
 // public
 QString kpGrip::haventBegunDrawUserMessage () const
 {
-    // TODO: "Left drag..." to be consistent
-    return i18n ("Drag the handle to resize the image.");
+    return i18n ("Left drag the handle to resize the image.");
 }
 
 
@@ -390,6 +389,7 @@ void kpGrip::paintEvent (QPaintEvent *e)
 }
 
 
+// TODO: Are we checking for m_view == 0 often enough?
 kpViewScrollableContainer::kpViewScrollableContainer (kpMainWindow *parent,
                                                       const char *name)
     : QScrollView ((QWidget *) parent, name, Qt::WStaticContents | Qt::WNoAutoErase),
@@ -515,8 +515,8 @@ QSize kpViewScrollableContainer::newDocSize (int viewDX, int viewDY) const
     if (!docResizingGrip ())
         return QSize ();
 
-    const int docX = m_view->transformViewToDocX (m_view->width () + viewDX);
-    const int docY = m_view->transformViewToDocY (m_view->height () + viewDY);
+    const int docX = (int) m_view->transformViewToDocX (m_view->width () + viewDX);
+    const int docY = (int) m_view->transformViewToDocY (m_view->height () + viewDY);
 
     return QSize (QMAX (1, docX), QMAX (1, docY));
 }
@@ -739,8 +739,8 @@ void kpViewScrollableContainer::updateResizeLines (int viewX, int viewY,
 
     if (viewX >= 0 && viewY >= 0)
     {
-        m_resizeRoundedLastViewX = m_view->transformDocToViewX (m_view->transformViewToDocX (viewX));
-        m_resizeRoundedLastViewY = m_view->transformDocToViewY (m_view->transformViewToDocY (viewY));
+        m_resizeRoundedLastViewX = (int) m_view->transformDocToViewX ((int) m_view->transformViewToDocX (viewX));
+        m_resizeRoundedLastViewY = (int) m_view->transformDocToViewY ((int) m_view->transformViewToDocY (viewY));
 
         m_resizeRoundedLastViewDX = viewDX;
         m_resizeRoundedLastViewDY = viewDY;
@@ -816,8 +816,8 @@ void kpViewScrollableContainer::slotGripContinuedDraw (int inViewDX, int inViewD
 
     m_haveMovedFromOriginalDocSize = true;
 
-    updateResizeLines (QMAX (1, QMAX (m_view->width () + viewDX, m_view->transformDocToViewX (1))),
-                       QMAX (1, QMAX (m_view->height () + viewDY, m_view->transformDocToViewY (1))),
+    updateResizeLines (QMAX (1, QMAX (m_view->width () + viewDX, (int) m_view->transformDocToViewX (1))),
+                       QMAX (1, QMAX (m_view->height () + viewDY, (int) m_view->transformDocToViewY (1))),
                        viewDX, viewDY);
 
     emit continuedDocResize (newDocSize ());
@@ -896,7 +896,6 @@ void kpViewScrollableContainer::recalculateStatusMessage ()
     //       any grip.  This also handles the case of cancelling over any
     //       grip.
     //
-    // TODO: "Left drag..." to be consistent
     if (kpWidgetMapper::toGlobal (this,
                                   QRect (0, 0, visibleWidth (), visibleHeight ()))
             .contains (QCursor::pos ()))
@@ -905,19 +904,19 @@ void kpViewScrollableContainer::recalculateStatusMessage ()
             m_bottomRightGrip->hotRect (true/*to global*/)
                 .contains (QCursor::pos ()))
         {
-            m_bottomRightGrip->setUserMessage (i18n ("Drag the handle to resize the image."));
+            m_bottomRightGrip->setUserMessage (i18n ("Left drag the handle to resize the image."));
         }
         else if (m_bottomGrip->isShown () &&
                 m_bottomGrip->hotRect (true/*to global*/)
                     .contains (QCursor::pos ()))
         {
-            m_bottomGrip->setUserMessage (i18n ("Drag the handle to resize the image."));
+            m_bottomGrip->setUserMessage (i18n ("Left drag the handle to resize the image."));
         }
         else if (m_rightGrip->isShown () &&
                 m_rightGrip->hotRect (true/*to global*/)
                     .contains (QCursor::pos ()))
         {
-            m_rightGrip->setUserMessage (i18n ("Drag the handle to resize the image."));
+            m_rightGrip->setUserMessage (i18n ("Left drag the handle to resize the image."));
         }
         else
         {
@@ -1329,6 +1328,19 @@ void kpViewScrollableContainer::mouseMoveEvent (QMouseEvent *e)
 }
 
 
+// protected virtual [base QScrollView]
+void kpViewScrollableContainer::contentsWheelEvent (QWheelEvent *e)
+{
+    e->ignore ();
+    
+    if (m_view)
+        m_view->wheelEvent (e);
+        
+    if (!e->isAccepted ())
+        QScrollView::contentsWheelEvent (e);
+}
+
+
 QRect kpViewScrollableContainer::noDragScrollRect () const
 {
     return QRect (DragScrollLeftTopMargin, DragScrollLeftTopMargin,
