@@ -5,7 +5,7 @@
     copyright            : (C) 2002 by Klaas Freitag
     email                : freitag@suse.de
 
-    $Id: thumbview.cpp,v 1.21 2003/10/29 12:47:13 freitag Exp $
+    $Id: thumbview.cpp 315131 2004-05-27 14:21:54Z freitag $
  ***************************************************************************/
 
 
@@ -210,6 +210,10 @@ void ThumbView::slImageRenamed( KFileItem *kfit, const KURL& newUrl )
 {
     const KURL url = kfit->url();
 
+    if( kfit->isDir() ) {
+	clear();
+    }
+    
     for ( QIconViewItem *item = m_iconView->firstItem(); item; item = item->nextItem() )
     {
         ThumbViewItem *it=static_cast<ThumbViewItem*>( item );
