@@ -3,7 +3,7 @@
  *                         <Christophe.Devriese@student.kuleuven.ac.be>    *
  *   Copyright (C) 2003 by Andy Goossens <andygoossens@telenet.be>         *
  *   Copyright (C) 2003 by Scott Wheeler <wheeler@kde.org>                 *
- *   Copyright (C) 2003 by Ingo Klcker <kloecker@kde.org>                 *
+ *   Copyright (C) 2003 by Ingo Klöcker <kloecker@kde.org>                 *
  *   Copyright (C) 2003 by Will Andrews <will@csociety.org>                *
  *   Copyright (C) 2004 by Dominique Devriese <devriese@kde.org>           *
  *   Copyright (C) 2004 by Waldo Bastian <bastian@kde.org>                 *
@@ -141,7 +141,7 @@ void KPDFOutputDev::endPage()
     SplashOutputDev::startPage( 0, NULL );
 }
 
-void KPDFOutputDev::drawLink( Link * link, Catalog * catalog )
+void KPDFOutputDev::processLink( Link * link, Catalog * catalog )
 {
     if ( !link->isOk() )
         return;
@@ -168,7 +168,7 @@ void KPDFOutputDev::drawLink( Link * link, Catalog * catalog )
             m_rects.push_front( rect );
         }
     }
-    SplashOutputDev::drawLink( link, catalog );
+    SplashOutputDev::processLink( link, catalog );
 }
 
 void KPDFOutputDev::drawImage( GfxState *state, Object *ref, Stream *str,
@@ -321,16 +321,23 @@ KPDFLink * KPDFOutputDev::generateLink( LinkAction * a )
     return link;
 }
 
-DocumentViewport KPDFOutputDev::decodeViewport( UGString * namedDest, LinkDest * dest )
+DocumentViewport KPDFOutputDev::decodeViewport( GString * namedDest, LinkDest * dest )
 // note: this function is called when processing a page, when the MUTEX is already LOCKED
 {
     DocumentViewport vp( -1 );
+    bool deleteDest = false;
 
     if ( namedDest && !dest )
+    {
+        deleteDest = true;
         dest = m_doc->findDest( namedDest );
+    }
 
     if ( !dest || !dest->isOk() )
+    {
+        if (deleteDest) delete dest;
         return vp;
+    }
 
     // get destination page number
     if ( !dest->isPageRef() )
@@ -383,6 +390,7 @@ DocumentViewport KPDFOutputDev::decodeViewport( UGString * namedDest, LinkDest *
             break;
     }
 
+    if (deleteDest) delete dest;
     return vp;
 }
 //END - private helpers
