@@ -186,9 +186,13 @@ Part::Part(QWidget *parentWidget, const char *widgetName,
 
 	int index;
 	// [left toolbox: Table of Contents] | []
-	m_tocFrame = new TOC( m_toolBox, m_document );
+	// dummy wrapper with layout to enable horizontal scroll bars (bug: 147233)
+	QWidget *tocWrapper = new QWidget(m_toolBox);
+	QVBoxLayout *tocWrapperLayout = new QVBoxLayout(tocWrapper);
+	m_tocFrame = new TOC( tocWrapper, m_document );
+	tocWrapperLayout->add(m_tocFrame);
 	connect(m_tocFrame, SIGNAL(hasTOC(bool)), this, SLOT(enableTOC(bool)));
-	index = m_toolBox->addItem( m_tocFrame, QIconSet(SmallIcon("text_left")), i18n("Contents") );
+	index = m_toolBox->addItem( tocWrapper, QIconSet(SmallIcon("text_left")), i18n("Contents") );
 	m_toolBox->setItemToolTip(index, i18n("Contents"));
 	enableTOC( false );
 
@@ -608,7 +612,7 @@ void Part::slotDoFileDirty()
     m_pageView->showText(i18n("Reloading the document..."), 0);
   }
 
-  if (KParts::ReadOnlyPart::openURL(m_file))
+  if (KParts::ReadOnlyPart::openURL(KURL::fromPathOrURL(m_file)))
   {
     if (m_viewportDirty.pageNumber >= (int)m_document->pages()) m_viewportDirty.pageNumber = (int)m_document->pages() - 1;
     m_document->setViewport(m_viewportDirty);
@@ -619,6 +623,7 @@ void Part::slotDoFileDirty()
     }
     if (m_wasPresentationOpen) slotShowPresentation();
     emit enablePrintAction(true);
+    emit setWindowCaption(url().filename());
   }
   else
   {
@@ -763,6 +768,7 @@ void Part::slotHistoryNext()
 
 void Part::slotFind()
 {
+    static bool savedCaseSensitive = false;
     KFindDialog dlg( widget() );
     dlg.setHasCursor( false );
     if ( !m_searchHistory.empty() )
@@ -772,12 +778,17 @@ void Part::slotFind()
     dlg.setSupportsWholeWordsFind( false );
     dlg.setSupportsRegularExpressionFind( false );
 #endif
+    if ( savedCaseSensitive )
+    {
+        dlg.setOptions( dlg.options() | KFindDialog::CaseSensitive );
+    }
     if ( dlg.exec() == QDialog::Accepted )
     {
+        savedCaseSensitive = dlg.options() & KFindDialog::CaseSensitive;
         m_searchHistory = dlg.findHistory();
         m_searchStarted = true;
         m_document->resetSearch( PART_SEARCH_ID );
-        m_document->searchText( PART_SEARCH_ID, dlg.pattern(), false, dlg.options() & KFindDialog::CaseSensitive,
+        m_document->searchText( PART_SEARCH_ID, dlg.pattern(), false, savedCaseSensitive,
                                 KPDFDocument::NextMatch, true, qRgb( 255, 255, 64 ) );
     }
 }
@@ -804,7 +815,7 @@ void Part::slotSaveFileAs()
                 return;
         }
 
-        if ( !KIO::NetAccess::file_copy( url(), saveURL, -1, true ) )
+        if ( !KIO::NetAccess::file_copy( m_file, saveURL, -1, true ) )
             KMessageBox::information( 0, i18n("File could not be saved in '%1'. Try to save it to another location.").arg( saveURL.prettyURL() ) );
     }
 }
@@ -983,7 +994,10 @@ void Part::slotShowProperties()
 void Part::slotShowPresentation()
 {
     if ( !m_presentationWidget )
+    {
       m_presentationWidget = new PresentationWidget( widget(), m_document );
+        m_presentationWidget->setupActions( actionCollection() );
+    }
 }
 
 void Part::slotHidePresentation()
@@ -992,6 +1006,19 @@ void Part::slotHidePresentation()
         delete (PresentationWidget*) m_presentationWidget;
 }
 
+void Part::slotTogglePresentation()
+{
+    if ( m_document->isOpened() )
+    {
+        if ( !m_presentationWidget )
+        {
+            m_presentationWidget = new PresentationWidget( widget(), m_document );
+            m_presentationWidget->setupActions( actionCollection() );
+        }
+        else delete (PresentationWidget*) m_presentationWidget;
+    }
+}
+
 void Part::slotPrint()
 {
     if (m_document->pages() == 0) return;
