@@ -59,53 +59,6 @@
 // definition of searchID for this class
 #define PAGEVIEW_SEARCH_ID 2
 
-class PageViewTip : public QToolTip
-{
-    public:
-        PageViewTip( PageView * view )
-            : QToolTip( view->viewport() ), m_view( view )
-        {
-        }
-
-        ~PageViewTip()
-        {
-            remove( m_view->viewport() );
-        }
-
-
-    protected:
-        void maybeTip( const QPoint &p );
-
-    private:
-        PageView * m_view;
-};
-
-void PageViewTip::maybeTip( const QPoint &_p )
-{
-    QPoint p( _p.x() + m_view->contentsX(), _p.y() + m_view->contentsY() );
-    PageViewItem * pageItem = m_view->pickItemOnPoint( p.x(), p.y() );
-    if ( pageItem )
-    {
-        double nX = (double)(p.x() - pageItem->geometry().left()) / (double)pageItem->width(),
-               nY = (double)(p.y() - pageItem->geometry().top()) / (double)pageItem->height();
-
-        // if over a ObjectRect (of type Link) change cursor to hand
-        const ObjectRect * object = pageItem->page()->hasObject( ObjectRect::Link, nX, nY );
-        if ( object )
-        {
-            // set tooltip over link's rect
-            KPDFLink *link = (KPDFLink *)object->pointer();
-            QString strtip = link->linkTip();
-            if ( !strtip.isEmpty() )
-            {
-                QRect linkRect = object->geometry( pageItem->width(), pageItem->height() );
-                linkRect.moveBy( - m_view->contentsX() + pageItem->geometry().left(), - m_view->contentsY() + pageItem->geometry().top() );
-                tip( linkRect, strtip );
-            }
-        }
-    }
-}
-
 // structure used internally by PageView for data storage
 class PageViewPrivate
 {
@@ -165,6 +118,55 @@ public:
 
 
 
+class PageViewTip : public QToolTip
+{
+    public:
+        PageViewTip( PageView * view )
+            : QToolTip( view->viewport() ), m_view( view )
+        {
+        }
+
+        ~PageViewTip()
+        {
+            remove( m_view->viewport() );
+        }
+
+
+    protected:
+        void maybeTip( const QPoint &p );
+
+    private:
+        PageView * m_view;
+};
+
+void PageViewTip::maybeTip( const QPoint &_p )
+{
+    QPoint p( _p.x() + m_view->contentsX(), _p.y() + m_view->contentsY() );
+    PageViewItem * pageItem = m_view->pickItemOnPoint( p.x(), p.y() );
+    if ( pageItem && m_view->d->mouseMode == PageView::MouseNormal )
+    {
+        double nX = (double)(p.x() - pageItem->geometry().left()) / (double)pageItem->width(),
+               nY = (double)(p.y() - pageItem->geometry().top()) / (double)pageItem->height();
+
+        // if over a ObjectRect (of type Link) change cursor to hand
+        const ObjectRect * object = pageItem->page()->hasObject( ObjectRect::Link, nX, nY );
+        if ( object )
+        {
+            // set tooltip over link's rect
+            KPDFLink *link = (KPDFLink *)object->pointer();
+            QString strtip = link->linkTip();
+            if ( !strtip.isEmpty() )
+            {
+                QRect linkRect = object->geometry( pageItem->width(), pageItem->height() );
+                linkRect.moveBy( - m_view->contentsX() + pageItem->geometry().left(), - m_view->contentsY() + pageItem->geometry().top() );
+                tip( linkRect, strtip );
+            }
+        }
+    }
+}
+
+
+
 /* PageView. What's in this file? -> quick overview.
  * Code weight (in rows) and meaning:
  *  160 - constructor and creating actions plus their connected slots (empty stuff)
@@ -1605,7 +1607,7 @@ void PageView::updateCursor( const QPoint &p )
 {
     // detect the underlaying page (if present)
     PageViewItem * pageItem = pickItemOnPoint( p.x(), p.y() );
-    if ( pageItem )
+    if ( pageItem && d->mouseMode == MouseNormal )
     {
         double nX = (double)(p.x() - pageItem->geometry().left()) / (double)pageItem->width(),
                nY = (double)(p.y() - pageItem->geometry().top()) / (double)pageItem->height();
