@@ -27,7 +27,9 @@ PageViewMessage::PageViewMessage( QWidget * parent )
     setFocusPolicy( NoFocus );
     setBackgroundMode( NoBackground );
     setPaletteBackgroundColor(kapp->palette().color(QPalette::Active, QColorGroup::Background));
-    move( 10, 10 );
+    // if the layout is LtR, we can safely place it in the right position
+    if ( !QApplication::reverseLayout() )
+        move( 10, 10 );
     resize( 0, 0 );
     hide();
 }
@@ -49,7 +51,8 @@ void PageViewMessage::display( const QString & message, Icon icon, int durationM
     int width = textRect.width(),
         height = textRect.height(),
         textXOffset = 0,
-        shadowOffset = message.isRightToLeft() ? -1 : 1;
+        iconXOffset = 0,
+        shadowOffset = 1;
 
     // load icon (if set) and update geometry
     QPixmap symbol;
@@ -70,8 +73,15 @@ void PageViewMessage::display( const QString & message, Icon icon, int durationM
                 symbol = SmallIcon( "messagebox_info" );
                 break;
         }
-        textXOffset = 2 + symbol.width();
-        width += textXOffset;
+        if ( QApplication::reverseLayout() )
+        {
+            iconXOffset = 2 + textRect.width();
+        }
+        else
+        {
+            textXOffset = 2 + symbol.width();
+        }
+        width += 2 + symbol.width();
         height = QMAX( height, symbol.height() );
     }
     QRect geometry( 0, 0, width + 10, height + 8 );
@@ -97,7 +107,7 @@ void PageViewMessage::display( const QString & message, Icon icon, int durationM
 
     // draw icon if present
     if ( !symbol.isNull() )
-        bufferPainter.drawPixmap( 5, 4, symbol, 0, 0, symbol.width(), symbol.height() );
+        bufferPainter.drawPixmap( 5 + iconXOffset, 4, symbol, 0, 0, symbol.width(), symbol.height() );
 
     // draw shadow and text
     int yText = geometry.height() - height / 2;
@@ -106,6 +116,11 @@ void PageViewMessage::display( const QString & message, Icon icon, int durationM
     bufferPainter.setPen( foregroundColor() );
     bufferPainter.drawText( 5 + textXOffset, yText, message );
 
+    // if the layout is RtL, we can move it to the right place only after we
+    // know how much size it will take
+    if ( QApplication::reverseLayout() )
+        move( parentWidget()->width() - geometry.width() - 10, 10 );
+
     // show widget and schedule a repaint
     show();
     update();
