@@ -52,7 +52,7 @@
 #include <X11/Xatom.h>
 #include <X11/Xmu/StdCmap.h>
 
-const double c_sizeFactor = log( 2 ) / 100.0;
+const double c_sizeFactor = log( 2.0 ) / 100.0;
 const int c_mouseChangeDelayPixel = 3;
 const int c_mouseChangeDelayMs = 300;
 const int c_multipleSelectDelayPixel = 3;
