@@ -21,11 +21,14 @@
 #include "pmmemento.h"
 
 const bool c_defaultNoShadow = false;
+const bool c_defaultNoImage = false;
+const bool c_defaultNoReflection = false;
+const bool c_defaultDoubleIlluminate = false;
 const int c_defaultVisibilityLevel = 0;
 const bool c_defaultRelativeVisibility = true;
 const bool c_defaultExport = true;
 
-PMDefinePropertyClass( PMGraphicalObject, PMProperty );
+PMDefinePropertyClass( PMGraphicalObject, PMGraphicalObjectProperty );
 
 PMMetaObject* PMGraphicalObject::s_pMetaObject = 0;
 
@@ -33,6 +36,9 @@ PMGraphicalObject::PMGraphicalObject( PMPart* part )
       : Base( part )
 {
    m_noShadow = c_defaultNoShadow;
+   m_noImage = c_defaultNoImage;
+   m_noReflection = c_defaultNoReflection;
+   m_doubleIlluminate = c_defaultDoubleIlluminate;
    m_visibilityLevel = c_defaultVisibilityLevel;
    m_relativeVisibility = c_defaultRelativeVisibility;
    m_export = c_defaultExport;
@@ -42,6 +48,9 @@ PMGraphicalObject::PMGraphicalObject( const PMGraphicalObject& o )
       : Base( o )
 {
    m_noShadow = o.m_noShadow;
+   m_noImage = o.m_noImage;
+   m_noReflection = o.m_noReflection;
+   m_doubleIlluminate = o.m_doubleIlluminate;
    m_visibilityLevel = o.m_visibilityLevel;
    m_relativeVisibility = o.m_relativeVisibility;
    m_export = o.m_export;
@@ -57,16 +66,25 @@ PMMetaObject* PMGraphicalObject::metaObject( ) const
    {
       s_pMetaObject = new PMMetaObject( "GraphicalObject", Base::metaObject( ) );
       s_pMetaObject->addProperty(
-         new PMProperty( "noShadow", &PMGraphicalObject::setNoShadow,
+         new PMGraphicalObjectProperty( "noShadow", &PMGraphicalObject::setNoShadow,
                          &PMGraphicalObject::noShadow ) );
       s_pMetaObject->addProperty(
-         new PMProperty( "visibilityLevel", &PMGraphicalObject::setVisibilityLevel,
+         new PMGraphicalObjectProperty( "noImage", &PMGraphicalObject::setNoImage,
+                         &PMGraphicalObject::noImage ) );
+      s_pMetaObject->addProperty(
+         new PMGraphicalObjectProperty( "noReflection", &PMGraphicalObject::setNoReflection,
+                         &PMGraphicalObject::noReflection ) );
+      s_pMetaObject->addProperty(
+         new PMGraphicalObjectProperty( "doubleIlluminate", &PMGraphicalObject::setDoubleIlluminate,
+                         &PMGraphicalObject::doubleIlluminate ) );
+      s_pMetaObject->addProperty(
+         new PMGraphicalObjectProperty( "visibilityLevel", &PMGraphicalObject::setVisibilityLevel,
                          &PMGraphicalObject::visibilityLevel ) );
       s_pMetaObject->addProperty(
-         new PMProperty( "relativeVisibilityLevel", &PMGraphicalObject::setVisibilityLevelRelative,
+         new PMGraphicalObjectProperty( "relativeVisibilityLevel", &PMGraphicalObject::setVisibilityLevelRelative,
                          &PMGraphicalObject::isVisibilityLevelRelative ) );
       s_pMetaObject->addProperty(
-         new PMProperty( "export", &PMGraphicalObject::setExportPovray,
+         new PMGraphicalObjectProperty( "export", &PMGraphicalObject::setExportPovray,
                          &PMGraphicalObject::exportPovray ) );
    }
    return s_pMetaObject;
@@ -85,6 +103,9 @@ void PMGraphicalObject::cleanUp( ) const
 void PMGraphicalObject::serialize( QDomElement& e, QDomDocument& doc ) const
 {
    e.setAttribute( "no_shadow", m_noShadow );
+   e.setAttribute( "no_image", m_noImage );
+   e.setAttribute( "no_reflection", m_noReflection );
+   e.setAttribute( "double_illuminate", m_doubleIlluminate );
    e.setAttribute( "visibility_level", m_visibilityLevel );
    e.setAttribute( "relative_visibility", m_relativeVisibility );
    e.setAttribute( "export", m_export );
@@ -94,6 +115,10 @@ void PMGraphicalObject::serialize( QDomElement& e, QDomDocument& doc ) const
 void PMGraphicalObject::readAttributes( const PMXMLHelper& h )
 {
    m_noShadow = h.boolAttribute( "no_shadow", c_defaultNoShadow );
+   m_noImage = h.boolAttribute( "no_image", c_defaultNoImage );
+   m_noReflection = h.boolAttribute( "no_reflection", c_defaultNoReflection );
+   m_doubleIlluminate = h.boolAttribute( "double_illuminate",
+                                         c_defaultDoubleIlluminate );
    m_visibilityLevel = h.intAttribute( "visibility_level",
                                        c_defaultVisibilityLevel );
    m_relativeVisibility = h.boolAttribute( "relative_visibility",
@@ -112,6 +137,36 @@ void PMGraphicalObject::setNoShadow( bool yes )
    }
 }
 
+void PMGraphicalObject::setNoImage( bool yes )
+{
+   if( m_noImage != yes )
+   {
+      if( m_pMemento )
+         m_pMemento->addData( s_pMetaObject, PMNoImageID, m_noImage );
+      m_noImage = yes;
+   }
+}
+
+void PMGraphicalObject::setNoReflection( bool yes )
+{
+   if ( m_noReflection != yes )
+   {
+      if( m_pMemento )
+         m_pMemento->addData( s_pMetaObject, PMNoReflectionID, m_noReflection );
+      m_noReflection = yes;
+   }
+}
+
+void PMGraphicalObject::setDoubleIlluminate( bool yes )
+{
+   if( m_doubleIlluminate != yes )
+   {
+      if( m_pMemento )
+         m_pMemento->addData( s_pMetaObject, PMDoubleIlluminateID, m_doubleIlluminate );
+      m_doubleIlluminate = yes;
+   }
+}
+
 void PMGraphicalObject::setVisibilityLevel( int level )
 {
    if( m_visibilityLevel != level )
@@ -165,6 +220,15 @@ void PMGraphicalObject::restoreMemento( PMMemento* s )
             case PMNoShadowID:
                setNoShadow( data->boolData( ) );
                break;
+            case PMNoImageID:
+               setNoImage( data->boolData( ) );
+               break;
+            case PMNoReflectionID:
+               setNoReflection( data->boolData( ) );
+               break;
+            case PMDoubleIlluminateID:
+               setDoubleIlluminate( data->boolData( ) );
+               break;
             case PMVisibilityID:
                setVisibilityLevel( data->intData( ) );
                break;
