@@ -538,7 +538,7 @@ void PMObjectSettings::applySettings( )
       PMSphereSweep::setSSteps( m_pSphereSweepSSteps->value( ) );
       repaint = true;
    }
-   if( PMHeightField::variance( ) != m_pHeightFieldVariance->value( ) );
+   if( PMHeightField::variance( ) != m_pHeightFieldVariance->value( ) )
    {
       PMHeightField::setVariance( m_pHeightFieldVariance->value( ) );
       repaint = true;
