@@ -702,6 +702,11 @@ public slots:
    /** Set the scene object. Must be used with extreme care. */
    void setScene( PMScene* scene );
 
+	/**
+	 * Emits the aboutToSave signal
+	 */
+	void slotAboutToSave( );
+
 signals:
    /**
     * Signal that is emitted when an object is changed.
@@ -735,6 +740,12 @@ signals:
     * Views should ask the user to save pending changes.
     */
    void aboutToRender( );
+   /**
+    * Emitted before the scene is saved or exported
+    *
+    * Views should ask the user to save pending changes.
+    */
+   void aboutToSave( );
 
 protected:
    /**
