@@ -34,6 +34,12 @@
 #include "pmspheresweep.h"
 #include "pmfinish.h"
 #include "pmmesh.h"
+#include "pmmedia.h"
+#include "pmgraphicalobject.h"
+#include "pmpigment.h"
+#include "pmtexture.h"
+#include "pmbicubicpatch.h"
+#include "pmtriangle.h"
 
 const PMIsoSurface::ContainedByType c_defaultIsoContainedBy = PMIsoSurface::Box;
 const PMVector c_defaultIsoCorner1 = PMVector( -1, -1, -1 );
@@ -587,10 +593,10 @@ void PMPov35SerInterior( const PMObject* object, const PMMetaObject* metaObject,
       str1.setNum( o->fadeDistance( ) );
       dev->writeLine( "fade_distance " + str1 );
    }
-   if( o->isFadeDistanceEnabled( ) )
+   if( o->isFadePowerEnabled( ) )
    {
-      str1.setNum( o->fadeDistance( ) );
-      dev->writeLine( "fade_distance " + str1 );
+      str1.setNum( o->fadePower( ) );
+      dev->writeLine( "fade_power " + str1 );
    }
    dev->objectEnd( );
 }
@@ -600,7 +606,7 @@ void PMPov35SerLightGroup( const PMObject* object, const PMMetaObject* metaObjec
    PMLightGroup* o = ( PMLightGroup* ) object;
 
    dev->objectBegin( "light_group" );
-   
+
    dev->writeName( object->name( ) );
    dev->callSerialization( object, metaObject->superClass( ) );
 
@@ -612,6 +618,19 @@ void PMPov35SerLightGroup( const PMObject* object, const PMMetaObject* metaObjec
    dev->objectEnd( );
 }
 
+const PMVector c_defaultPatternCrackleForm = PMVector( -1.0, 1.0, 0.0 );
+const int c_defaultPatternCrackleMetric = 2;
+const double c_defaultPatternCrackleOffset = 0.0;
+const bool c_defaultPatternCrackleSolid = false;
+const int c_defaultPatternFractalExponent = 2;
+const int c_defaultPatternFractalExtType = 1;
+const double c_defaultPatternFractalExtFactor = 1.0;
+const int c_defaultPatternFractalIntType = 0;
+const double c_defaultPatternFractalIntFactor = 1.0;
+const double c_defaultPatternSlopeLoSlope = 0.0;
+const double c_defaultPatternSlopeHiSlope = 1.0;
+const double c_defaultPatternSlopeLoAlt = 0.0;
+const double c_defaultPatternSlopeHiAlt = 1.0;
 const int c_defaultPatternOctaves = 6;
 const double c_defaultPatternOmega = 0.5;
 const double c_defaultPatternLambda = 2.0;
@@ -620,7 +639,7 @@ void PMPov35SerPattern( const PMObject* object, const PMMetaObject*, PMOutputDev
 {
    PMPattern* o = ( PMPattern* ) object;
 
-   QString str;
+   QString str, str2;
 
    // pattern type
    switch( o->patternType( ) )
@@ -640,6 +659,9 @@ void PMPov35SerPattern( const PMObject* object, const PMMetaObject*, PMOutputDev
       case PMPattern::PatternBumps:
          dev->writeLine( "bumps" );
          break;
+      case PMPattern::PatternCells:
+         dev->writeLine( "cells" );
+         break;
       case PMPattern::PatternCrackle:
          dev->writeLine( "crackle" );
          break;
@@ -658,12 +680,33 @@ void PMPov35SerPattern( const PMObject* object, const PMMetaObject*, PMOutputDev
       case PMPattern::PatternGranite:
          dev->writeLine( "granite" );
          break;
+      case PMPattern::PatternJulia:
+         if( o->fractalMagnet( ) )
+         {
+            str.setNum( o->fractalMagnetType( ) );
+            str = "magnet " + str + " ";
+         }
+         else
+            str = "";
+
+         str2.setNum( o->maxIterations( ) );
+         str = str + "julia " + o->juliaComplex( ).serialize( ) + ", " + str2;
+         dev->writeLine( str );
+         break;
       case PMPattern::PatternLeopard:
          dev->writeLine( "leopard" );
          break;
       case PMPattern::PatternMandel:
-         str.setNum( o->maxIterations( ) );
-         dev->writeLine( "mandel " + str );
+         if( o->fractalMagnet( ) )
+         {
+            str.setNum( o->fractalMagnetType( ) );
+            str = "magnet " + str + " ";
+         }
+         else
+            str = "";
+
+         str2.setNum( o->maxIterations( ) );
+         dev->writeLine( str + "mandel " + str2 );
          break;
       case PMPattern::PatternMarble:
          dev->writeLine( "marble" );
@@ -683,6 +726,34 @@ void PMPov35SerPattern( const PMObject* object, const PMMetaObject*, PMOutputDev
       case PMPattern::PatternRipples:
          dev->writeLine( "ripples" );
          break;
+      case PMPattern::PatternSlope:
+         dev->objectBegin( "slope" );
+         dev->write( o->slopeDirection( ).serialize( ) );
+         if ( o->slopeLoSlope( ) != c_defaultPatternSlopeLoSlope ||
+               o->slopeHiSlope( ) != c_defaultPatternSlopeHiSlope )
+         {
+            str.setNum( o->slopeLoSlope( ) );
+            str2.setNum( o->slopeHiSlope( ) );
+            dev->writeLine( ", " + str + ", " + str2 );
+         }
+         else
+            dev->writeLine( "" );
+
+         if ( o->slopeAltFlag( ) )
+         {
+            dev->write( "altitude " + o->slopeAltitude( ).serialize( ) );
+            if ( o->slopeLoAltitude( ) != c_defaultPatternSlopeLoAlt ||
+                  o->slopeHiAltitude( ) != c_defaultPatternSlopeHiAlt )
+            {
+               str.setNum( o->slopeLoAltitude( ) );
+               str2.setNum( o->slopeHiAltitude( ) );
+               dev->writeLine( ", " + str + ", " + str2 );
+            }
+            else
+               dev->writeLine( "" );
+         }
+         dev->objectEnd( );
+         break;
       case PMPattern::PatternSpherical:
          dev->writeLine( "spherical" );
          break;
@@ -723,10 +794,48 @@ void PMPov35SerPattern( const PMObject* object, const PMMetaObject*, PMOutputDev
          str.setNum( o->agateTurbulence( ) );
          dev->writeLine( "agate_turb " + str );
          break;
+      case PMPattern::PatternCrackle:
+         if ( o->crackleForm( ) != c_defaultPatternCrackleForm )
+            dev->writeLine( "form " + o->crackleForm( ).serialize( ) );
+         if ( o->crackleMetric( ) != c_defaultPatternCrackleMetric )
+         {
+            str.setNum( o->crackleMetric( ) );
+            dev->writeLine( "metric " + str );
+         }
+         if ( o->crackleOffset( ) != c_defaultPatternCrackleOffset )
+         {
+            str.setNum( o->crackleOffset( ) );
+            dev->writeLine( "offset " + str );
+         }
+         if ( o->crackleSolid( ) )
+            dev->writeLine( "solid" );
+         break;
       case PMPattern::PatternDensity:
          str.setNum( o->densityInterpolate( ) );
          dev->writeLine( "interpolate " + str );
          break;
+      case PMPattern::PatternJulia:
+      case PMPattern::PatternMandel:
+         if ( !o->fractalMagnet( ) && o->fractalExponent( ) != c_defaultPatternFractalExponent )
+         {
+            str.setNum( o->fractalExponent( ) );
+            dev->writeLine( "exponent " + str );
+         }
+         if ( o->fractalExtType( ) != c_defaultPatternFractalExtType ||
+               o->fractalExtFactor( ) != c_defaultPatternFractalExtFactor )
+         {
+            str.setNum( o->fractalExtType( ) );
+            str2.setNum( o->fractalExtFactor( ) );
+            dev->writeLine( "exterior " + str + ", " + str2 );
+         }
+         if ( o->fractalIntType( ) != c_defaultPatternFractalIntType ||
+               o->fractalIntFactor( ) != c_defaultPatternFractalIntFactor )
+         {
+            str.setNum( o->fractalIntType( ) );
+            str2.setNum( o->fractalIntFactor( ) );
+            dev->writeLine( "interior " + str + ", " + str2 );
+         }
+         break;
       case PMPattern::PatternQuilted:
          str.setNum( o->quiltControl0( ) );
          dev->writeLine( "control0 " + str );
@@ -786,11 +895,17 @@ void PMPov35SerNormal( const PMObject* object, const PMMetaObject* metaObject, P
    bool bObject = true;
 
    if( o->parent( ) )
+   {
       if( o->parent( )->type( ) == "NormalMap" )
          bObject = false;
+   }
 
    if( bObject )
+   {
       dev->objectBegin( "normal" );
+      if ( o->uvMapping() )
+         dev->writeLine( "uv_mapping" );
+   }
 
    dev->callSerialization( object, metaObject->superClass( ) );
 
@@ -1117,3 +1232,240 @@ void PMPov35SerMesh( const PMObject* object, const PMMetaObject* metaObject, PMO
 
    dev->objectEnd( );
 }
+
+const int c_defaultMediaMethod = 1;
+const int c_defaultMediaIntervals = 10;
+const int c_defaultMediaSamplesMin = 1;
+const int c_defaultMediaSamplesMax = 1;
+const double c_defaultMediaConfidence = 0.9;
+const double c_defaultMediaVariance = 0.0078125;
+const double c_defaultMediaRatio = 0.9;
+const int c_defaultMediaAALevel = 4;
+const double c_defaultMediaAAThreshold = 0.1;
+const double c_defaultMediaScatteringEccentricity = 0;
+const double c_defaultMediaScatteringExtinction = 1.0;
+
+void PMPov35SerMedia( const PMObject* object, const PMMetaObject* metaObject, PMOutputDevice* dev )
+{
+   PMMedia* o = ( PMMedia* ) object;
+
+   QString str1;
+   QString str2;
+
+   dev->objectBegin( "media" );
+   dev->callSerialization( object, metaObject->superClass( ) );
+
+   if( o->method( ) != c_defaultMediaMethod )
+   {
+      str1.setNum( o->method( ) );
+      dev->writeLine( "method " + str1 );
+   }
+   if( o->intervals( ) != c_defaultMediaIntervals )
+   {
+      str1.setNum( o->intervals( ) );
+      dev->writeLine( "intervals " + str1 );
+   }
+   if( o->samplesMin( ) != c_defaultMediaSamplesMin ||
+       o->samplesMax( ) != c_defaultMediaSamplesMax )
+   {
+      str1.setNum( o->samplesMin( ) );
+      str2.setNum( o->samplesMax( ) );
+      if ( o->method( ) < 3 )
+         dev->writeLine( "samples " + str1 + "," + str2 );
+      else
+         dev->writeLine( "samples " + str1 );
+   }
+   if( o->confidence( ) != c_defaultMediaConfidence )
+   {
+      str1.setNum( o->confidence( ) );
+      dev->writeLine( "confidence " + str1 );
+   }
+   if( o->variance( ) != c_defaultMediaVariance )
+   {
+      str1.setNum( o->variance( ) );
+      dev->writeLine( "variance " + str1 );
+   }
+   if( o->ratio( ) != c_defaultMediaRatio )
+   {
+      str1.setNum( o->ratio( ) );
+      dev->writeLine( "ratio " + str1 );
+   }
+   if ( o->method( ) == 3 )
+   {
+      if ( o->aaLevel( ) != c_defaultMediaAALevel )
+      {
+         str1.setNum( o->aaLevel( ) );
+         dev->writeLine( "aa_level " + str1 );
+      }
+      if ( o->aaThreshold( ) != c_defaultMediaAAThreshold )
+      {
+         str1.setNum( o->aaThreshold( ) );
+         dev->writeLine( "aa_threshold " + str1 );
+      }
+   }
+   if( o->isAbsorptionEnabled( ) )
+   {
+      dev->writeLine( "absorption " + o->absorption( ).serialize( ) );
+   }
+   if( o->isEmissionEnabled( ) )
+   {
+      dev->writeLine( "emission " + o->emission( ).serialize( ) );
+   }
+   if( o->isScatteringEnabled( ) )
+   {
+      dev->objectBegin( "scattering" );
+      str1.setNum( o->scatteringType( ) );
+      dev->writeLine( str1 + ", " + o->scatteringColor( ).serialize( ) );
+      if( o->scatteringType( ) == 5 && o->scatteringEccentricity( )
+          != c_defaultMediaScatteringEccentricity )
+      {
+         str1.setNum( o->scatteringEccentricity( ) );
+         dev->writeLine( "eccentricity " + str1 );
+      }
+      if( o->scatteringExtinction( ) != c_defaultMediaScatteringExtinction )
+      {
+         str1.setNum( o->scatteringExtinction( ) );
+         dev->writeLine( "extinction " + str1 );
+      }
+      dev->objectEnd( );
+   }
+   dev->objectEnd( );
+}
+
+void PMPov35SerGraphicalObject( const PMObject* object, const PMMetaObject* metaObject, PMOutputDevice* dev )
+{
+   PMGraphicalObject* o = ( PMGraphicalObject* ) object;
+
+   dev->callSerialization( object, metaObject->superClass( ) );
+
+   if( o->noShadow( ) )
+      dev->writeLine( "no_shadow" );
+
+   if( o->noImage( ) )
+      dev->writeLine( "no_image" );
+
+   if( o->noReflection( ) )
+      dev->writeLine( "no_reflection" );
+
+   if( o->doubleIlluminate( ) )
+      dev->writeLine( "double_illuminate" );
+}
+
+void PMPov35SerPigment( const PMObject* object, const PMMetaObject* metaObject, PMOutputDevice* dev )
+{
+   PMPigment* o = ( PMPigment* ) object;
+
+   bool bObject = true;
+   if( o->parent( ) )
+      if( o->parent( )->type( ) == "PigmentMap" )
+         bObject = false;
+
+   if( bObject )
+   {
+      dev->objectBegin( "pigment" );
+      if ( o->uvMapping() )
+         dev->writeLine( "uv_mapping" );
+   }
+   dev->callSerialization( object, metaObject->superClass( ) );
+   if( bObject )
+      dev->objectEnd( );
+}
+
+void PMPov35SerTexture( const PMObject* object, const PMMetaObject* metaObject, PMOutputDevice* dev )
+{
+   PMTexture* o = ( PMTexture* ) object;
+
+   bool bObject = true;
+   if( o->parent( ) )
+      if( o->parent( )->type( ) == "TextureMap" )
+         bObject = false;
+
+   if( bObject )
+   {
+      dev->objectBegin( "texture" );
+      if ( o->uvMapping() )
+         dev->writeLine( "uv_mapping" );
+   }
+   dev->callSerialization( object, metaObject->superClass( ) );
+   if( bObject )
+      dev->objectEnd( );
+}
+
+const double c_defaultPatchFlatness = 0;
+
+void PMPov35SerBicubicPatch( const PMObject* object, const PMMetaObject* metaObject, PMOutputDevice* dev )
+{
+   PMBicubicPatch* o = ( PMBicubicPatch* ) object;
+
+   int u, v;
+   QString str, line;
+   dev->objectBegin( "bicubic_patch" );
+
+   dev->writeName( object->name( ) );
+
+   str.setNum( o->patchType( ) );
+   dev->writeLine( "type " + str );
+   if( !approx( o->flatness( ), c_defaultPatchFlatness ) )
+   {
+      str.setNum( o->flatness( ) );
+      dev->writeLine( "flatness " + str );
+   }
+   str.setNum( o->uSteps( ) );
+   dev->writeLine( "u_steps " + str );
+   str.setNum( o->vSteps( ) );
+   dev->writeLine( "v_steps " + str );
+
+   if( o->isUVEnabled( ) )
+   {
+      dev->writeLine( "uv_vectors " + o->uvVector( 0 ).serialize( ) +
+                      " " + o->uvVector( 1 ).serialize( ) +
+                      " " + o->uvVector( 2 ).serialize( ) +
+                      " " + o->uvVector( 3 ).serialize( ) );
+   }
+
+   for( v = 0; v < 4; v++ )
+   {
+      line = o->controlPoint( v*4 ).serialize( );
+      for( u = 1; u < 4; u++ )
+         line += QString( ", " ) + o->controlPoint( u+4*v ).serialize( );
+      if( v != 3 )
+         line += ",";
+      dev->writeLine( line );
+   }
+
+   dev->callSerialization( object, metaObject->superClass( ) );
+   dev->objectEnd( );
+}
+
+void PMPov35SerTriangle( const PMObject* object, const PMMetaObject* metaObject, PMOutputDevice* dev )
+{
+   PMTriangle* o = ( PMTriangle* ) object;
+
+   if( o->isSmoothTriangle( ) )
+   {
+      dev->objectBegin( "smooth_triangle" );
+
+      dev->writeName( object->name( ) );
+      dev->writeLine( o->point( 0 ).serialize( ) + ", " + o->normal( 0 ).serialize( ) + "," );
+      dev->writeLine( o->point( 1 ).serialize( ) + ", " + o->normal( 1 ).serialize( ) + "," );
+      dev->writeLine( o->point( 2 ).serialize( ) + ", " + o->normal( 2 ).serialize( ) );
+   }
+   else
+   {
+      dev->objectBegin( "triangle" );
+
+      dev->writeName( object->name( ) );
+      dev->writeLine( o->point( 0 ).serialize( ) + ", " + o->point( 1 ).serialize( )
+                     + ", " + o->point( 2 ).serialize( ) );
+   }
+
+   if( o->isUVEnabled( ) )
+   {
+      dev->writeLine( "uv_vectors " + o->uvVector( 0 ).serialize( ) +
+                      " " + o->uvVector( 1 ).serialize( ) +
+                      " " + o->uvVector( 2 ).serialize( ) );
+   }
+
+   dev->callSerialization( object, metaObject->superClass( ) );
+   dev->objectEnd( );
+}
