@@ -47,6 +47,7 @@ PMReservedWordDict::PMReservedWordDict( PMDictMode mode )
          insert( "all", new int( ALL_TOK ) );
          insert( "all_intersections", new int( ALL_INTERSECTIONS_TOK ) );
          insert( "alpha", new int( ALPHA_TOK ) );
+         insert( "altitude", new int( ALTITUDE_TOK ) );
          insert( "always_sample", new int ( ALWAYS_SAMPLE_TOK ) );
          insert( "ambient", new int( AMBIENT_TOK ) );
          insert( "ambient_light", new int( AMBIENT_LIGHT_TOK ) );
@@ -94,6 +95,7 @@ PMReservedWordDict::PMReservedWordDict( PMDictMode mode )
          insert( "ceil", new int( CEIL_TOK ) );
          insert( "checker", new int( CHECKER_TOK ) );
          insert( "chr", new int( CHR_TOK ) );
+         insert( "cells", new int( CELLS_TOK ) );
          insert( "clipped_by", new int( CLIPPED_BY_TOK ) );
          insert( "clock", new int( CLOCK_TOK ) );
          insert( "clock_delta", new int( CLOCK_DELTA_TOK ) );
@@ -140,6 +142,7 @@ PMReservedWordDict::PMReservedWordDict( PMDictMode mode )
          insert( "distance", new int( DISTANCE_TOK ) );
          insert( "distance_maximum", new int( DISTANCE_MAXIMUM_TOK ) );
          insert( "div", new int( DIV_TOK ) );
+         insert( "double_illuminate", new int( DOUBLE_ILLUMINATE_TOK ) );
          insert( "dust", new int( DUST_TOK ) );
          insert( "dust_type", new int( DUST_TYPE_TOK ) );
          insert( "eccentricity", new int( ECCENTRICITY_TOK ) );
@@ -151,6 +154,7 @@ PMReservedWordDict::PMReservedWordDict( PMDictMode mode )
          insert( "exp", new int( EXP_TOK ) );
          insert( "expand_thresholds", new int (EXPAND_THRESHOLDS_TOK) );
          insert( "exponent", new int( EXPONENT_TOK ) );
+         insert( "exterior", new int( EXTERIOR_TOK ) );
          insert( "extinction", new int( EXTINCTION_TOK ) );
          insert( "fade_distance", new int( FADE_DISTANCE_TOK ) );
          insert( "fade_power", new int( FADE_POWER_TOK ) );
@@ -169,7 +173,7 @@ PMReservedWordDict::PMReservedWordDict( PMDictMode mode )
          insert( "fog_alt", new int( FOG_ALT_TOK ) );
          insert( "fog_offset", new int( FOG_OFFSET_TOK ) );
          insert( "fog_type", new int( FOG_TYPE_TOK ) );
-         insert( "fractal", new int( FRACTAL_TOK ) );
+         insert( "form", new int( FORM_TOK ) );
          insert( "fresnel", new int( FRESNEL_TOK ) );
          insert( "frequency", new int( FREQUENCY_TOK ) );
          insert( "function", new int( FUNCTION_TOK ) );
@@ -205,6 +209,7 @@ PMReservedWordDict::PMReservedWordDict( PMDictMode mode )
          insert( "irid_wavelength", new int( IRID_WAVELENGTH_TOK ) );
          insert( "isosurface", new int( ISOSURFACE_TOK ) );
          insert( "jitter", new int( JITTER_TOK ) );
+         insert( "julia", new int( JULIA_TOK ) );
          insert( "julia_fractal", new int( JULIA_FRACTAL_TOK ) );
          insert( "lambda", new int( LAMBDA_TOK ) );
          insert( "lathe", new int( LATHE_TOK ) );
@@ -219,6 +224,7 @@ PMReservedWordDict::PMReservedWordDict( PMDictMode mode )
          insert( "looks_like", new int( LOOKS_LIKE_TOK ) );
          insert( "look_at", new int( LOOK_AT_TOK ) );
          insert( "low_error_factor", new int( LOW_ERROR_FACTOR_TOK ) );
+         insert( "magnet", new int ( MAGNET_TOK ) );
          insert( "major_radius", new int( MAJOR_RADIUS_TOK ) );
          insert( "mandel", new int( MANDEL_TOK ) );
          insert( "map_type", new int( MAP_TYPE_TOK ) );
@@ -240,6 +246,8 @@ PMReservedWordDict::PMReservedWordDict( PMDictMode mode )
          insert( "merge", new int( MERGE_TOK ) );
          insert( "mesh", new int( MESH_TOK ) );
          insert( "metallic", new int( METALLIC_TOK ) );
+         insert( "method", new int( METHOD_TOK ) );
+         insert( "metric", new int( METRIC_TOK ) );
          insert( "min", new int( MIN_TOK ) );
          insert( "minimum_reuse", new int( MINIMUM_REUSE_TOK ) );
          insert( "mod", new int( MOD_TOK ) );
@@ -249,6 +257,8 @@ PMReservedWordDict::PMReservedWordDict( PMDictMode mode )
          insert( "noise_generator", new int( NOISE_GENERATOR_TOK ) );
          insert( "normal", new int( NORMAL_TOK ) );
          insert( "normal_map", new int( NORMAL_MAP_TOK ) );
+         insert( "no_image", new int( NO_IMAGE_TOK ) );
+         insert( "no_reflection", new int( NO_REFLECTION_TOK ) );
          insert( "no_shadow", new int( NO_SHADOW_TOK ) );
          insert( "number_of_waves", new int( NUMBER_OF_WAVES_TOK ) );
          insert( "object", new int( OBJECT_TOK ) );
@@ -336,9 +346,11 @@ PMReservedWordDict::PMReservedWordDict( PMDictMode mode )
          insert( "sky", new int( SKY_TOK ) );
          insert( "sky_sphere", new int( SKY_SPHERE_TOK ) );
          insert( "slice", new int( SLICE_TOK ) );
+         insert( "slope", new int( SLOPE_TOK ) );
          insert( "slope_map", new int( SLOPE_MAP_TOK ) );
          insert( "smooth", new int( SMOOTH_TOK ) );
          insert( "smooth_triangle", new int( SMOOTH_TRIANGLE_TOK ) );
+         insert( "solid", new int( SOLID_TOK ) );
          insert( "sor", new int( SOR_TOK ) );
          insert( "spacing", new int ( SPACING_TOK ) );
          insert( "specular", new int( SPECULAR_TOK ) );
@@ -401,6 +413,8 @@ PMReservedWordDict::PMReservedWordDict( PMDictMode mode )
          insert( "use_colour", new int( USE_COLOUR_TOK ) );
          insert( "use_index", new int( USE_INDEX_TOK ) );
          insert( "u_steps", new int( U_STEPS_TOK ) );
+         insert( "uv_mapping", new int( UV_MAPPING_TOK ) );
+         insert( "uv_vectors", new int( UV_VECTORS_TOK ) );
          insert( "v", new int( V_TOK ) );
          insert( "val", new int( VAL_TOK ) );
          insert( "variance", new int( VARIANCE_TOK ) );
