@@ -137,7 +137,7 @@ public:
     * @param topPage The page created with addVBoxPage
     * @param page The internal settings page
     */
-   void registerPage( QWidget* page, PMSettingsDialogPage* page );
+   void registerPage( QWidget* topPage, PMSettingsDialogPage* page );
 
    static void saveConfig( KConfig* cfg );
    static void restoreConfig( KConfig* cfg );
