@@ -65,7 +65,7 @@ void PMSurfaceOfRevolutionEdit::createBottomWidgets( )
    bl->addWidget( m_pRemove );
    bl->addStretch( 1 );
    
-   m_pOpen = new QCheckBox( i18n( "Open" ), this );
+   m_pOpen = new QCheckBox( i18n( "type of the object", "Open" ), this );
    topLayout( )->addWidget( m_pOpen );
    connect( m_pOpen, SIGNAL( clicked( ) ), SIGNAL( dataChanged( ) ) );
    m_pSturm = new QCheckBox( i18n( "Sturm" ), this );
