@@ -139,7 +139,7 @@ bool PMTextureMapEdit::isDataValid( )
          return false;
       if( it.current( )->value( ) < last )
       {
-         KMessageBox::error( this, i18n( "The map values have to be increasing" ),
+         KMessageBox::error( this, i18n( "The map values have to be increasing." ),
                              i18n( "Error" ) );
          it.current( )->setFocus( );
          return false;
