@@ -69,13 +69,13 @@ public:
 
    int columnWidth( ) const { return m_columnWidth; }
    void setColumnWidth( int i );
-   
+
    int height( ) const { return m_height; }
    void setHeight( int i );
 
    int floatingHeight( ) const { return m_floatingHeight; }
    void setFloatingHeight( int h ) { m_floatingHeight = h; }
-   
+
    int floatingWidth( ) const { return m_floatingWidth; }
    void setFloatingWidth( int w ) { m_floatingWidth = w; }
 
@@ -92,7 +92,7 @@ public:
 
    const QString dockPositionAsString( );
    const QString viewTypeAsString( );
-   
+
 private:
    QString m_viewType;
    PMDockWidget::DockPosition m_dockPosition;
@@ -145,13 +145,13 @@ public:
    /**
     * Sets the name of the layout
     */
-   void setName( QString n );
+   void setName( const QString& n );
    /**
-    * 
-    * Add a new entry to the layout. By default it adds the entry at the end 
+    *
+    * Add a new entry to the layout. By default it adds the entry at the end
     * of the list. If a position is given it adds the entry at the indicated
     * position
-    */ 
+    */
    void addEntry( const PMViewLayoutEntry& e, int index = -1 );
    /**
     * Removes the entry at the given position
@@ -187,12 +187,12 @@ private:
       QValueList< QValueList< PMViewLayoutEntry > >& cols,
       QValueList< QValueList< PMViewLayoutEntry > >::iterator cit,
       int width, QWidget* widget );
-   
+
    static void recursiveExtractOneColumn(
       QValueList< PMViewLayoutEntry >& entries,
       QValueList< PMViewLayoutEntry >::iterator eit,
       int height, QWidget* widget );
-   
+
    QString m_name;
    QValueList< PMViewLayoutEntry > m_entries;
 };
@@ -284,7 +284,7 @@ private:
    QValueList< PMViewLayout > m_layouts;
 
    static PMViewLayoutManager* s_pInstance;
-   static KStaticDeleter<PMViewLayoutManager> s_staticDeleter;   
+   static KStaticDeleter<PMViewLayoutManager> s_staticDeleter;
 };
 
 
