@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <math.h>
@@ -401,10 +401,12 @@ void SVGPathElementImpl::svgClosePath()
 // Ecma stuff
 
 /*
+@namespace KSVG
 @begin SVGPathElementImpl::s_hashTable 3
  d											SVGPathElementImpl::D										DontDelete|ReadOnly
  pathLength									SVGPathElementImpl::PathLength								DontDelete|ReadOnly
 @end
+@namespace KSVG
 @begin SVGPathElementImplProto::s_hashTable 23
  getTotalLength								SVGPathElementImpl::GetTotalLength							DontDelete|Function 0
  getPointAtLength							SVGPathElementImpl::GetPointAtLength						DontDelete|Function 1
@@ -467,7 +469,7 @@ void SVGPathElementImpl::putValueProperty(ExecState *exec, int token, const Valu
 	// it's allowed to modify those.
 	if(!(attr & KJS::Internal))
 		return;
-	
+
 	switch(token)
 	{
 		case D:
@@ -572,6 +574,12 @@ void SVGPathElementImpl::createItem(KSVGCanvas *c)
 
 	if(!m_item)
 	{
+		// TODO : this is a quick fix for this problem:
+		// d attribute encountered before marker attributes.
+		// Try to process the attributes in the right order, ie.
+		// d attr processing should be last.
+		if(hasMarkers() && m_markerData.numMarkers() == 0)
+			m_markerData = MarkerData(pathSegList());
 		m_item = c->createPath(this);
 		c->insert(m_item);
 	}
