@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <kdebug.h>
@@ -148,6 +148,7 @@ SVGMatrixImpl *SVGPreserveAspectRatioImpl::getCTM(float logicX, float logicY, fl
 // Ecma stuff
 
 /*
+@namespace KSVG
 @begin SVGPreserveAspectRatioImpl::s_hashTable 3
  align			SVGPreserveAspectRatioImpl::Align   	 DontDelete
  meetOrSlice	SVGPreserveAspectRatioImpl::MeetOrSlice  DontDelete
@@ -184,6 +185,7 @@ void SVGPreserveAspectRatioImpl::putValueProperty(ExecState *exec, int token, co
 }
 
 /*
+@namespace KSVG
 @begin SVGPreserveAspectRatioImplConstructor::s_hashTable 17
  SVG_PRESERVEASPECTRATIO_UNKNOWN	KSVG::SVG_PRESERVEASPECTRATIO_UNKNOWN		DontDelete|ReadOnly
  SVG_PRESERVEASPECTRATIO_NONE		KSVG::SVG_PRESERVEASPECTRATIO_NONE			DontDelete|ReadOnly
