@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <kdebug.h>
@@ -188,10 +188,12 @@ void SVGTextContentElementImpl::selectSubString(const unsigned long &charnum,con
 // Ecma stuff
 
 /*
+@namespace KSVG
 @begin SVGTextContentElementImpl::s_hashTable 3
  textLength				SVGTextContentElementImpl::TextLength						DontDelete|ReadOnly
  lengthAdjust			SVGTextContentElementImpl::LengthAdjust						DontDelete|ReadOnly
 @end
+@namespace KSVG
 @begin SVGTextContentElementImplProto::s_hashTable 11
  getNumberOfChars		SVGTextContentElementImpl::GetNumberOfChars					DontDelete|Function 0
  getComputedTextLength	SVGTextContentElementImpl::GetComputedTextLength			DontDelete|Function 0
@@ -262,6 +264,7 @@ Value SVGTextContentElementImplProtoFunc::call(ExecState *exec, Object &thisObj,
 }
 
 /*
+@namespace KSVG
 @begin SVGTextContentElementImplConstructor::s_hashTable 5
  LENGTHADJUST_UNKNOWN      		KSVG::LENGTHADJUST_UNKNOWN				DontDelete|ReadOnly
  LENGTHADJUST_SPACING      		KSVG::LENGTHADJUST_SPACING				DontDelete|ReadOnly
