@@ -129,11 +129,13 @@ KuickShow::KuickShow( const char *name )
     int numArgs = args->count();
     if ( numArgs >= 10 )
     {
+        // Even though the 1st i18n string will never be used, it needs to exist for plural handling - mhunter
         if ( KMessageBox::warningYesNo(
                  this,
-                 i18n("Do you really want to display these %1 images at the same time? This might be quite resource intensive and could overload your computer.\nIf you choose %2, only the first image will be shown.").arg(numArgs).arg(KStdGuiItem::no().plainText()),
-                 i18n("Display %1 images?").arg(numArgs))
-             != KMessageBox::Yes)
+                 i18n("Do you really want to display this 1 image at the same time? This might be quite resource intensive and could overload your computer.<br>If you choose %1, only the first image will be shown.", 
+                      "Do you really want to display these %n images at the same time? This might be quite resource intensive and could overload your computer.<br>If you choose %1, only the first image will be shown.", numArgs).arg(KStdGuiItem::no().plainText()),
+                 i18n("Display Multiple Images?"))
+             != KMessageBox::Yes )
         {
             numArgs = 1;
         }
@@ -190,7 +192,8 @@ KuickShow::KuickShow( const char *name )
 
     if ( s_viewers.isEmpty() || isDir ) {
         initGUI( startDir );
-        show();
+	if (!kapp->isRestored()) // during session management, readProperties() will show()
+            show();
     }
 
     else { // don't show browser, when image on commandline
@@ -522,7 +525,7 @@ void KuickShow::showFileItem( ImageWindow * /*view*/,
 
 }
 
-void KuickShow::showImage( const KFileItem *fi,
+bool KuickShow::showImage( const KFileItem *fi,
                            bool newWindow, bool fullscreen, bool moveToTopLeft )
 {
     newWindow  |= !m_viewer;
@@ -593,8 +596,11 @@ void KuickShow::showImage( const KFileItem *fi,
             }
 
             m_viewer = safeViewer;
+	    return true;
         } // m_viewer created successfully
     } // isImage
+
+    return false;
 }
 
 void KuickShow::slotDeleteCurrentImage()
@@ -654,6 +660,8 @@ void KuickShow::performTrashCurrentImage(QWidget *parent)
 
     KFileItemList list;
     KFileItem *item = fileWidget->getCurrentItem(false);
+    if (!item) return;
+
     list.append (item);
 
     if (KMessageBox::warningContinueCancel(
@@ -1144,25 +1152,32 @@ void KuickShow::readProperties( KConfig *kc )
         fileWidget->clearHistory();
     }
 
+    const KURL& listedURL = fileWidget->url();
     QStringList images = kc->readPathListEntry( "Images shown" );
     QStringList::Iterator it;
+    bool hasCurrentURL = false;
+
     for ( it = images.begin(); it != images.end(); ++it ) {
         KFileItem item( KFileItem::Unknown, KFileItem::Unknown, KURL::fromPathOrURL( *it ), false );
         if ( item.isReadable() )
-            showImage( &item, true );
+            if ( showImage( &item, true ) ) {
+	        // Set the current URL in the file widget, if possible
+                if ( !hasCurrentURL && listedURL.isParentOf( item.url() ))
+                    fileWidget->setInitialItem( item.url().fileName() );
+		    hasCurrentURL = true;
+	    }
     }
 
-    if ( !s_viewers.isEmpty() ) {
-        bool visible = kc->readBoolEntry( "Browser visible", true );
-        if ( !visible )
-            hide();
-    }
+    bool visible = kc->readBoolEntry( "Browser visible", false );
+    if ( visible || s_viewers.isEmpty() )
+        show();
 }
 
 void KuickShow::saveProperties( KConfig *kc )
 {
-    kc->writePathEntry( "CurrentDirectory", fileWidget->url().url() );
-    kc->writeEntry( "Browser visible", fileWidget->isVisible() );
+    kc->writeEntry( "Browser visible", fileWidget && fileWidget->isVisible() );
+    if (fileWidget)
+        kc->writePathEntry( "CurrentDirectory", fileWidget->url().url() );
 
     QStringList urls;
     QValueListIterator<ImageWindow*> it;
