@@ -227,11 +227,11 @@ public:
    has actually been used. A default implementation is provided. */
   virtual double setZoom(double z);
   
-  /* reads in settings */
-  virtual void readSettings() {}
+  /** reads in settings. Reimplementations must call this. */
+  virtual void readSettings();
   
-  /* writes settings */
-  virtual void writeSettings() {}
+  /** writes settings. Reimplementations must call this. */
+  virtual void writeSettings();
   
   /** Flag to indicate that this implementation has support for textserach and selection */
   virtual bool supportsTextSearch() const { return getRenderer() && getRenderer()->supportsTextSearch(); }
