@@ -1,18 +1,16 @@
-#ifndef __KVIEWSHELL_H__
-#define __KVIEWSHELL_H__
-
+// -*- C++ -*-
+#ifndef KVIEWSHELL_H
+#define KVIEWSHELL_H
 
 #include <qstring.h>
-#include <qevent.h>
-
 
 #include <kparts/mainwindow.h>
-#include <kurl.h>
-
 
 class KRecentFilesAction;
+class KURL;
 class KViewPart_Iface;
 
+
 class QLabel;
 
 class KViewShell : public KParts::MainWindow
@@ -23,7 +21,7 @@ public:
   KStatusBar *statusbar;
   KStatusBar *action;
 
-  KViewShell(QString defaultMimeType = QString::null);
+  KViewShell(const QString& defaultMimeType = QString::null);
   virtual ~KViewShell();
 
 public slots:
