@@ -1,3 +1,4 @@
+// -*- C++ -*-
 // pageSizeWidget.h
 //
 // Part of KVIEWSHELL - A framework for multipage text/gfx viewers
@@ -25,18 +26,18 @@ public:
   // Sets the page size. If the dialog is already shown, updates all
   // the GUI. Accepts the same strings as input as the setPageSize()
   // method of the pageSize() class.
-  void setPageSize(QString);
+  void setPageSize(const QString&);
 
   void setOrientation(int ori);
 
-  const pageSize &pageSizeData(void) const {return chosenSize;};
+  const pageSize &pageSizeData() const {return chosenSize;}
 
 protected slots:
   void paperSize(int);
-  void fillTextFields(void);
+  void fillTextFields();
 
   // Dummy function, for convenience. Ignores the argument and calls
-  // the fillTextFields(void) slot.
+  // the fillTextFields() slot.
   void unitsChanged(int);
   void orientationChanged(int = 0);
   void input(const QString &);
