@@ -1,4 +1,4 @@
-// sizePreview.cpp
+// SizePreview.cpp
 //
 // Part of KVIEWSHELL - A framework for multipage text/gfx viewers
 //
@@ -7,25 +7,29 @@
 
 // Add header files alphabetically
 
-#include <kdebug.h> 
+#include <config.h>
+
+#include <kdebug.h>
 #include <krandomsequence.h>
 #include <qevent.h>
 #include <qpainter.h>
 
 #include "sizePreview.h"
 
-sizePreview::sizePreview( QWidget *parent, const char *name, WFlags f )
-    : QWidget( parent, name, f  )
+#include "simplePageSize.h"
+
+SizePreview::SizePreview( QWidget *parent, const char *name, WFlags)
+    : QWidget( parent, name, WStaticContents | WNoAutoErase )
 {
   // Set a sane default
   _width = _height = 50.0;
   orientation = 0; // Portrait
 }
 
-void sizePreview::setSize(float width, float height)
+void SizePreview::setSize(const SimplePageSize& size)
 {
-  _width = width;
-  _height = height;
+  _width = size.width().getLength_in_mm();
+  _height = size.height().getLength_in_mm();
 
   if (_width < 50.0)
     _width = 50.0;
@@ -36,11 +40,16 @@ void sizePreview::setSize(float width, float height)
     _height = 50.0;
   if (_height > 1200.0)
     _height = 1200.0;
-  
+
   update();
 }
 
-void sizePreview::paintEvent( QPaintEvent * )
+void SizePreview::resizeEvent(QResizeEvent*)
+{
+  update();
+}
+
+void SizePreview::paintEvent( QPaintEvent * )
 {
   int displayedWidth, displayedHeight;
 
@@ -62,8 +71,10 @@ void sizePreview::paintEvent( QPaintEvent * )
 
 
   // Now draw the graphics
-  erase();
-  QPainter p(this);
+  pixmap.resize(width(), height());
+
+  QPainter p(&pixmap);
+  p.fillRect(rect(), colorGroup().background());
   p.setPen(Qt::black);
   p.setBrush(Qt::white);
   p.drawRect(hOffset, vOffset, displayedWidth, displayedHeight);
@@ -76,18 +87,23 @@ void sizePreview::paintEvent( QPaintEvent * )
 
   // Draw some dummy "text", represented by black lines
   int lineSpacing    = (int)(7.0*displayedWidth/_width + 0.5); // equiv. 7 mm
-  if (lineSpacing <= 0)
+  if (lineSpacing <= 3)
     lineSpacing = 3;
   int interWordSpace = (int)(4.0*displayedWidth/_width + 0.5); // equiv. 4 mm
   if (interWordSpace <= 1)
     interWordSpace = 2;
 
-  KRandomSequence rnd(0); // to generate word widths
+  KRandomSequence rnd(1); // to generate word widths
 
   p.setClipRect(textBox);
   p.setPen(Qt::black);
   int count = 1; // Counts lines
   for (int y = vOffset+margin+lineSpacing; y <= vOffset+displayedHeight-margin; y += lineSpacing) {
+    // We start each line with its own seed.
+    // This means that the random sequence for each line is always the same, and this
+    // results in a more steady picture when the widget is resized.
+    rnd.setSeed(count);
+
     // Every 10th line the end of a paragraph
     int endParagraph;
     if (count++ % 10 == 0)
@@ -103,10 +119,13 @@ void sizePreview::paintEvent( QPaintEvent * )
   }
 
   p.end();
+
+  // Copy the pixmap onto the widget
+  bitBlt(this, rect().topLeft(), &pixmap, rect(), CopyROP);
   return;
 }
 
-void sizePreview::setOrientation(int ori)
+void SizePreview::setOrientation(int ori)
 {
   orientation = ori;
   update();
